@@ -37,9 +37,9 @@
 #include "AT_Constants.h"
 #include "AT_DataMaterial.h"
 #include "AT_DataParticle.h"
-#include "AT_DataStoppingPower.h"
 #include "AT_ElectronRange.h"
 #include "AT_NumericalRoutines.h"
+#include "AT_StoppingPower.h"
 
 /**
  *  Returns relativistic speed for single value of energy
